************
Installation
************

First you need to install the NeuNorm library

using pip


.. code-block:: html

    > pip install NeuNorm


or using conda

.. code-block:: html

    > conda install -c neutronimaging neunorm


Then in your python environment, import the library

>>> import NeuNorm as neunorm
>>> from NeuNorm.normalization import Normalization
>>> from NeuNorm.roi import ROI


